==> zio-aws-elasticsearch_2.12-5.17.129.3-sources.jar: zio/aws/elasticsearch/model/VPCOptions.scala <==
package zio.aws.elasticsearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class VPCOptions(
    subnetIds: Option[Iterable[String]] = None,
    securityGroupIds: Option[Iterable[String]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.VPCOptions = {
    import VPCOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.VPCOptions
      .builder()
      .optionallyWith(
        subnetIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.subnetIds)
      .optionallyWith(
        securityGroupIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.securityGroupIds)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.VPCOptions.ReadOnly =
    zio.aws.elasticsearch.model.VPCOptions.wrap(buildAwsValue())
}
object VPCOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.VPCOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.VPCOptions =
      zio.aws.elasticsearch.model.VPCOptions(
        subnetIds.map(value => value),
        securityGroupIds.map(value => value)
      )
    def subnetIds: Option[List[String]]
    def securityGroupIds: Option[List[String]]
    def getSubnetIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("subnetIds", subnetIds)
    def getSecurityGroupIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("securityGroupIds", securityGroupIds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.VPCOptions
  ) extends zio.aws.elasticsearch.model.VPCOptions.ReadOnly {
    override val subnetIds: Option[List[String]] = scala
      .Option(impl.subnetIds())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val securityGroupIds: Option[List[String]] = scala
      .Option(impl.securityGroupIds())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.VPCOptions
  ): zio.aws.elasticsearch.model.VPCOptions.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticsearch_2.13-5.17.171.1-sources.jar: zio/aws/elasticsearch/model/VPCOptions.scala <==
package zio.aws.elasticsearch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class VPCOptions(
    subnetIds: Optional[Iterable[String]] = Optional.Absent,
    securityGroupIds: Optional[Iterable[String]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.VPCOptions = {
    import VPCOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.VPCOptions
      .builder()
      .optionallyWith(
        subnetIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.subnetIds)
      .optionallyWith(
        securityGroupIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.securityGroupIds)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.VPCOptions.ReadOnly =
    zio.aws.elasticsearch.model.VPCOptions.wrap(buildAwsValue())
}
object VPCOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.VPCOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.VPCOptions =
      zio.aws.elasticsearch.model.VPCOptions(
        subnetIds.map(value => value),
        securityGroupIds.map(value => value)
      )
    def subnetIds: Optional[List[String]]
    def securityGroupIds: Optional[List[String]]
    def getSubnetIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("subnetIds", subnetIds)
    def getSecurityGroupIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("securityGroupIds", securityGroupIds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.VPCOptions
  ) extends zio.aws.elasticsearch.model.VPCOptions.ReadOnly {
    override val subnetIds: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.subnetIds())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val securityGroupIds: Optional[List[String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.securityGroupIds())
        .map(value =>
          value.asScala.map { item =>
            item: String
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.VPCOptions
  ): zio.aws.elasticsearch.model.VPCOptions.ReadOnly = new Wrapper(impl)
}
